
<!--
FrozenIsBool False
-->

#Pather

##Doc
----


> 
> A Pather use its __setitem__ method for setting attributes in deeper levels thanks to 
> the PathPrefixStr 
> 
> 

----

<small>
View the Pather notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Pather.ipynb)
</small>

